API documentation
-----------------

.. toctree::
   :maxdepth: 5

   Elasticipy.tensors.elasticity
   Elasticipy.tensors.fourth_order
   Elasticipy.tensors.second_order
   Elasticipy.tensors.stress_strain
   Elasticipy.tensors.thermal_expansion
   Elasticipy.plasticity
   Elasticipy.spherical_function
   Elasticipy.interfaces.PRISMS
   Elasticipy.interfaces.FEPX
